==> order-center-domain-3.1.0-CLOUD-DEV-20230112.134351-10-sources.jar: com/tydic/dyc/oc/model/chngorder/UocChngOrderDo.java <==
package com.tydic.dyc.oc.model.chngorder;

import com.tydic.dyc.oc.model.chngorder.sub.UocChngOrderItemMap;
import com.tydic.dyc.oc.model.chngorder.sub.UocChngOrderMap;
import com.tydic.dyc.oc.model.chngorder.sub.UocChngOrderObj;
import com.tydic.dyc.oc.model.order.sub.UocOrderAccessory;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocChngOrderDo
 * 说明:变更单
 * 时间:2022-03-08 17:49
 * 作者:罗有
 **/
@Data
public class UocChngOrderDo implements Serializable {
    private static final long serialVersionUID = 5980326960021296095L;

    @DocField(value = "变更单id")
    private Long chngOrderId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "业务类型 1:异常变更 2订单调价3订单取消")
    private Integer busiType;

    @DocField(value = "变更单编号")
    private String chngOrderNo;

    @DocField(value = "变更单状态")
    private String chngOrderState;

    @DocField(value = "变更单类型")
    private Integer chngType;

    @DocField(value = "变更单类型翻译")
    private String chngTypeStr;

    @DocField(value = "变更单状态 翻译")
    private String chngOrderStateStr;

    @DocField(value = "租户ID")
    private String tenantId;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "创建人名称")
    private String createOperName;

    @DocField(value = "创建手机号")
    private String createOperMobile;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "更新人名称")
    private String updateOperName;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "撤单时间")
    private Date cancelTime;

    @DocField(value = "撤单工号")
    private String cancelOperId;

    @DocField(value = "撤单人名称")
    private String cancelOperName;

    @DocField(value = "撤单原因")
    private String cancelReason;

    @DocField(value = "竣工时间")
    private Date finishTime;

    @DocField(value = "逾期时间")
    private Date expTime;

    @DocField(value = "拒绝原因")
    private String rejectReason;

    @DocField(value = "拒绝时间")
    private Date rejectTime;

    @DocField(value = "发货单编号")
    private String shipOrderNo;

    @DocField(value = "发货单状态")
    private String shipOrderState;

    @DocField(value = "发货单状态翻译")
    private String shipOrderStateStr;

    @DocField(value = "验收时间")
    private Date inspTime;

    @DocField(value = "验收人名称")
    private String inspOperName;

    @DocField(value = "验收金额")
    private BigDecimal inspSaleFee;

    @DocField(value = "扩展字段1")
    private String extField1;

    @DocField(value = "扩展字段2")
    private String extField2;

    @DocField(value = "扩展字段3")
    private String extField3;

    @DocField(value = "扩展字段4")
    private String extField4;

    @DocField(value = "扩展字段5")
    private String extField5;

    @DocField(value = "变更对象")
    private List<UocChngOrderObj> uocChngOrderObjList;

    @DocField(value = "变更扩展")
    private List<UocChngOrderMap> uocChngOrderMapList;

    @DocField(value = "附件")
    private List<UocOrderAccessory> orderAccessoryBoList;

    @DocField(value = "变更明细扩展")
    private List<UocChngOrderItemMap> uocChngOrderItemMapList;
}

==> order-center-domain-3.2.2-CLOUD-DEV-20240807.075428-55-sources.jar: com/tydic/dyc/oc/model/chngorder/UocChngOrderDo.java <==
package com.tydic.dyc.oc.model.chngorder;

import com.tydic.dyc.oc.model.chngorder.sub.UocChngOrderItemMap;
import com.tydic.dyc.oc.model.chngorder.sub.UocChngOrderMap;
import com.tydic.dyc.oc.model.chngorder.sub.UocChngOrderObj;
import com.tydic.dyc.oc.model.order.sub.UocOrderAccessory;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocChngOrderDo
 * 说明:变更单
 * 时间:2022-03-08 17:49
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocChngOrderDo implements Serializable {
    private static final long serialVersionUID = 5980326960021296095L;

    //变更单id")
    private Long chngOrderId;

    //订单id")
    private Long orderId;

    //业务类型 1:异常变更 2订单调价3订单取消")
    private Integer busiType;

    //变更单编号")
    private String chngOrderNo;

    //变更单状态")
    private String chngOrderState;

    //变更单类型")
    private Integer chngType;

    //变更单类型翻译")
    private String chngTypeStr;

    //变更单状态 翻译")
    private String chngOrderStateStr;

    //租户ID")
    private String tenantId;

    //创建时间")
    private Date createTime;

    //创建工号")
    private String createOperId;

    //创建人名称")
    private String createOperName;

    //创建手机号")
    private String createOperMobile;

    //更新时间")
    private Date updateTime;

    //更新工号")
    private String updateOperId;

    //更新人名称")
    private String updateOperName;

    //备注")
    private String remark;

    //删除标志1已删除")
    private Integer delTag;

    //撤单时间")
    private Date cancelTime;

    //撤单工号")
    private String cancelOperId;

    //撤单人名称")
    private String cancelOperName;

    //撤单原因")
    private String cancelReason;

    //竣工时间")
    private Date finishTime;

    //逾期时间")
    private Date expTime;

    //拒绝原因")
    private String rejectReason;

    //拒绝时间")
    private Date rejectTime;

    //发货单编号")
    private String shipOrderNo;

    //发货单状态")
    private String shipOrderState;

    //发货单状态翻译")
    private String shipOrderStateStr;

    //验收时间")
    private Date inspTime;

    //验收人名称")
    private String inspOperName;

    //验收金额")
    private BigDecimal inspSaleFee;
    //验收单状态")
    private String inspOrderState;

    //验收单状态翻译")
    private String inspOrderStateStr;
    //单据状态") 发货单或验收单
    private String objOrderState;

    //单据状态翻译") 发货单或验收单
    private String objOrderStateStr;

    //扩展字段1")
    private String extField1;

    //扩展字段2")
    private String extField2;

    //扩展字段3")
    private String extField3;

    //扩展字段4")
    private String extField4;

    //扩展字段5")
    private String extField5;

    //变更对象")
    private List<UocChngOrderObj> uocChngOrderObjList;

    //变更扩展")
    private List<UocChngOrderMap> uocChngOrderMapList;

    //附件")
    private List<UocOrderAccessory> orderAccessoryBoList;

    //变更明细扩展")
    private List<UocChngOrderItemMap> uocChngOrderItemMapList;
}
